Task: Task N' Talk
===================
Description: Dataset of synthetic shapes described by attributes, for agents to play a cooperative QA game, from Kottur et al. '17. 

Link: https://arxiv.org/abs/1706.08502

Tags: #TaskNTalk, #All, #Goal

